@@ -8,5 +8,5 @@ class Gasqualitaet(StrEnum):
     Unterscheidung für hoch- und niedrig-kalorisches Gas.
     """
 
-    H_GAS = "H_GAS"  # High Caloric Gas
-    L_GAS = "L_GAS"  # Low Caloric Gas
+    H_GAS = "H_GAS"  #: High Caloric Gas
+    L_GAS = "L_GAS"  #: Low Caloric Gas
