@@ -1,4 +1,4 @@
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.com.regionaleraufabschlag import RegionalerAufAbschlag
@@ -6,12 +6,12 @@ from bo4e.com.tarifeinschraenkung import Tarifeinschraenkung
 from bo4e.enum.aufabschlagstyp import AufAbschlagstyp
 from bo4e.enum.aufabschlagsziel import AufAbschlagsziel
 from bo4e.enum.waehrungseinheit import Waehrungseinheit
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
-from tests.test_energiemix import example_energiemix  # type:ignore[import]
-from tests.test_preisgarantie import example_preisgarantie  # type:ignore[import]
-from tests.test_regionalepreisstaffel import example_regionale_preisstaffel  # type:ignore[import]
-from tests.test_vertragskonditionen import example_vertragskonditionen  # type:ignore[import]
-from tests.test_zeitraum import example_zeitraum  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
+from tests.test_energiemix import example_energiemix
+from tests.test_preisgarantie import example_preisgarantie
+from tests.test_regionalepreisstaffel import example_regionale_preisstaffel
+from tests.test_vertragskonditionen import example_vertragskonditionen
+from tests.test_zeitraum import example_zeitraum
 
 example_regionaler_auf_abschlag = RegionalerAufAbschlag(
     bezeichnung="Foo",
