@@ -1,4 +1,4 @@
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.bo.tarifkosten import Tarifkosten
@@ -7,12 +7,12 @@ from bo4e.enum.sparte import Sparte
 from bo4e.enum.tarifart import Tarifart
 from bo4e.enum.tarifmerkmal import Tarifmerkmal
 from bo4e.enum.tariftyp import Tariftyp
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
-from tests.test_energiemix import example_energiemix  # type:ignore[import]
-from tests.test_kosten import example_kosten  # type:ignore[import]
-from tests.test_marktteilnehmer import example_marktteilnehmer  # type:ignore[import]
-from tests.test_vertragskonditionen import example_vertragskonditionen  # type:ignore[import]
-from tests.test_zeitraum import example_zeitraum  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
+from tests.test_energiemix import example_energiemix
+from tests.test_kosten import example_kosten
+from tests.test_marktteilnehmer import example_marktteilnehmer
+from tests.test_vertragskonditionen import example_vertragskonditionen
+from tests.test_zeitraum import example_zeitraum
 
 
 class TestTarifkosten:
