@@ -1,9 +1,9 @@
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.com.tarifpreispositionproort import TarifpreispositionProOrt
-from tests.serialization_helper import assert_serialization_roundtrip  # type:ignore[import]
-from tests.test_tarifpreisstaffelproort import example_tarifpreisstaffelproort  # type:ignore[import]
+from tests.serialization_helper import assert_serialization_roundtrip
+from tests.test_tarifpreisstaffelproort import example_tarifpreisstaffelproort
 
 example_tarifpreispositionproort = TarifpreispositionProOrt(
     postleitzahl="82031",
