@@ -1,7 +1,7 @@
 from datetime import datetime
 from decimal import Decimal
 
-import pytest  # type:ignore[import]
+import pytest
 from pydantic import ValidationError
 
 from bo4e.bo.zaehler import Zaehler
